@@ -9,6 +9,8 @@ import logging
 import queue
 import threading
 import uuid
+from decimal import Decimal
+from json import JSONEncoder
 from typing import Any
 from typing import List
 
@@ -46,6 +48,19 @@ class AtomicCounter:
         return str(self)
 
 
+class DecimalJsonEncoder(JSONEncoder):
+    """
+    This class is used to avoid an issue with the __verify_payload_format serialization check.
+    Normally, including data of type Decimal would cause that check to fail so we've amended
+    the default JsonEncoder object used to convert Decimal values to floats to avoid this issue.
+    """
+
+    def default(self, obj):
+        if isinstance(obj, Decimal):
+            return float(obj)
+        return super().default(obj)
+
+
 def get_page_generator(data, page_size=10000):
     # TODO add support for Pandas
     try:
@@ -92,9 +107,8 @@ def convert_table(table: iter, column_names: iter) -> List[dict]:
     for row in table:
         cdf_row = dict()
         for index, value in enumerate(row):
-            if value is not None:
-                value = _handle_special_types(value)
-                cdf_row[column_names[index]] = value
+            value = _handle_special_types(value)
+            cdf_row[column_names[index]] = value
         converted_rows.append(cdf_row)
 
     return converted_rows
